@@ -30,12 +30,17 @@ class EquilibriumConditions:
         if "temperature" in input_params:
             temp_params=input_params["temperature"]
             if "tempK_min" in temp_params:
-                temp_min=temp_params["tempK_min"]
-            else:
-                print(" ERROR(temperatures):: missed tempK_min")
+                print(" Error:: temK_min(max) were changed to tempK_start(end)")
+                print("         Other parameters to set a parameter range were also.")
+                print(" Very sorry for this forced chage!")
                 sys.exit()
-            if "tempK_max" in temp_params:
-                temp_max=temp_params["tempK_max"]
+            if "tempK_start" in temp_params:
+                temp_min=temp_params["tempK_start"]
+            else:
+                print(" ERROR(temperatures):: missed tempK_start")
+                sys.exit()
+            if "tempK_end" in temp_params:
+                temp_max=temp_params["tempK_end"]
             else:
                 temp_max=temp_min
             if "tempK_num" in temp_params:
@@ -71,9 +76,14 @@ class EquilibriumConditions:
                 if "numCell_array" in params2:
                     nat2_array=params2["numCell_array"]
                 if "numCell_min" in params2:
-                    nat2_min=params2["numCell_min"]
-                if "numCell_max" in params2:
-                    nat2_max=params2["numCell_max"]
+                    print(" Error:: numCell_min(max) were changed to numCell_start(end)")
+                    print("         Other parameters to set a parameter range were also.")
+                    print(" Very sorry for this forced chage!")
+                    sys.exit()
+                if "numCell_start" in params2:
+                    nat2_min=params2["numCell_start"]
+                if "numCell_end" in params2:
+                    nat2_max=params2["numCell_end"]
                 if "numCell_num" in params2:
                     nat2_num=params2["numCell_num"]
                 if "numCell_log" in params2:
@@ -90,7 +100,7 @@ class EquilibriumConditions:
                         print(" ERROR(eq.fix_Natoms):: missed numCell_num for "+e2)
                         sys.exit()
                     if nat2_min=="NONE":
-                        print(" ERROR(eq.fix_Natoms):: missed numCell_min for "+e2)
+                        print(" ERROR(eq.fix_Natoms):: missed numCell_start for "+e2)
                         sys.exit()
                     if nat2_max=="NONE":
                         nat2_max=nat2_min
@@ -182,17 +192,22 @@ class EquilibriumConditions:
                     if not "label" in params2:
                         print(" ERROR(eq.fix_chempots.gas_pressures):: missed label")
                         sys.exit()
-                    if not "pressPa_min" in params2:
-                        print(" ERROR(eq.fix_chempots.gas_pressures):: missed pressPa_min")
+                    if "pressPa_min" in params2:
+                        print(" Error:: pressPa_min(max) were changed to pressPa_start(end)")
+                        print("         Other parameters to set a parameter range were also.")
+                        print(" Very sorry for this forced chage!")
+                        sys.exit()
+                    if not "pressPa_start" in params2:
+                        print(" ERROR(eq.fix_chempots.gas_pressures):: missed pressPa_start")
                         sys.exit()
                     if "scale_log" in params2:
                         scale_log=params2["scale_log"]
                     else:
                         scale_log=True
                     l1=params2["label"]
-                    pmin=params2["pressPa_min"]
-                    if "pressPa_max" in params2:
-                        pmax=params2["pressPa_max"]
+                    pmin=params2["pressPa_start"]
+                    if "pressPa_end" in params2:
+                        pmax=params2["pressPa_end"]
                     else:
                         pmax=pmin
                     if "pressPa_num" in params2:
